#!/usr/bin/python2

# Test Agilent 34401A
import Gpib
import vxi11
import os.path
import sys
import time
from BME280 import *

LogDir = '/pub/logs/'
LogFile= LogDir + '34401A_DCV_Log.csv'
Reflevel = 1.018
sd_buffer = 100 # How many measurements to commit to SD card (to limit writes)

# Sensors
BME_Enabled = 2
if (BME_Enabled == 1):
  BMEsensorA = BME280(address=0x76)
if (BME_Enabled == 2):
  BMEsensorA = BME280(address=0x76)
  BMEsensorB = BME280(address=0x77)

# 34401A GPIB
inst = Gpib.Gpib(0,10)
#34420A LAN
#inst = Gpib.Gpib(0,20)
# 34410A LAN
#inst = vxi11.Instrument("192.168.0.27", "gpib0,20")

inst.clear()  
inst.write("*IDN?")
print(inst.read())

#Setup Agilent 34420A
inst.write("*RST")
inst.write("SYST:PRES")
inst.write("*CLS")

# DCV 34401A/34420A
inst.write(":CONFigure:VOLTage:DC 1,MAXimum")
#inst.write(":SENSe:VOLTage:DC:RANGe 10")
#inst.write(":SENSe:VOLTage:DC:NPLCycles 100")
inst.write("VOLT:DC:NPLC 10")
#inst.write("TRIG:COUN 10")
inst.write("INPut:IMPedance:AUTO ON")

# Ratio
#inst.write(":CONFigure:VOLTage:DC:RATio 10")

# 4W Ohms
#inst.write(":CONFigure:FRESistance 10000,MAX")
#inst.write(":SENSe:FRESistance:RANGe 10000")
#inst.write(":SENSe:FRESistance:NPLCycles 100")

inst.write(":DISPlay ON")

# Check file presence, write header
if (os.path.isfile(LogFile) == False):
  with open(LogFile, 'a') as MeterLog:
    if (BME_Enabled == 1):
       MeterLog.write("TimeStamp,Voltage,ppm,Temperature,Pressure,Humidity\r\n")
    elif (BME_Enabled == 2):
       MeterLog.write("TimeStamp,Voltage,ppm,Temp A,Pressure A,Humidity A, Temp B, Pressure B, Humidity B\r\n")
    else:
       MeterLog.write("TimeStamp,Voltage,ppm\r\n")
    MeterLog.close()

while True:
    with open(LogFile, 'a') as MeterLog:
      sd_count=1
      while sd_count-1<sd_buffer:     
        inst.write("READ?")
        data = inst.read()
        ppm = ((float(data) / Reflevel)-1)*1E6
        if (BME_Enabled == 1):
          # Reads sensor data
          Temperature = BMEsensorA.read_temperature()
          Pressure = BMEsensorA.read_pressure()
          Humidity = BMEsensorA.read_humidity()
          print str(sd_count) + ('/') + str(sd_buffer) + (' ') + time.strftime("%d/%m/%Y\t%H:%M:%S") + ("\t%.7f\t%.2f ppm\t%4.2f\t%6.0f\t%4.1f\r\n" % (float(data),float(ppm),float(Temperature),float(Pressure),float(Humidity)) )
          MeterLog.write (time.strftime("%d/%m/%Y-%H:%M:%S,") + ("%.7f,%.2f,%4.2f,%6.0f,%4.1f\r\n" % (float(data),float(ppm),float(Temperature),float(Pressure),float(Humidity))))
        elif (BME_Enabled == 2):
          TemperatureA = BMEsensorA.read_temperature()
          PressureA = BMEsensorA.read_pressure()
          HumidityA = BMEsensorA.read_humidity()
          TemperatureB = BMEsensorB.read_temperature()
          PressureB = BMEsensorB.read_pressure()
          HumidityB = BMEsensorB.read_humidity()
          print str(sd_count) + ('/') + str(sd_buffer) + (' ') + time.strftime("%d/%m/%Y\t%H:%M:%S") + ("\t%.7f\t%.2f ppm\t%4.2f\t%6.0f\t%4.1f\t%4.2f\t%6.0f\t%4.1f\r\n" % (float(data),float(ppm),float(TemperatureA),float(PressureA),float(HumidityA),float(TemperatureB),float(PressureB),float(HumidityB)) )
          MeterLog.write (time.strftime("%d/%m/%Y-%H:%M:%S,") + ("%.7f,%.2f,%4.2f,%6.0f,%4.1f,%4.2f,%6.0f,%4.1f\r\n" % (float(data),float(ppm),float(TemperatureA),float(PressureA),float(HumidityA),float(TemperatureB),float(PressureB),float(HumidityB))))
        else:
	  print str(sd_count) + ('/') + str(sd_buffer) + (' ') + time.strftime("%d/%m/%Y\t%H:%M:%S") + ("\t%.7f\t%.2f ppm" % (float(data),float(ppm) ) )
	  MeterLog.write (time.strftime("%d/%m/%Y-%H:%M:%S,") + ("%.7f,%.2f\r\n" % (float(data),float(ppm) ) ))
        sd_count=sd_count+1
      MeterLog.close()
      print ('************************************************')
      print ('*                                              *')
      print ('*        Committed to SD Card                  *')
      print ('*                                              *')
      print ('************************************************')  
